tests package
=============

Submodules
----------

tests.compare\_headers module
-----------------------------

.. automodule:: tests.compare_headers
   :members:
   :undoc-members:
   :show-inheritance:

tests.context module
--------------------

.. automodule:: tests.context
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_archive\_file module
--------------------------------

.. automodule:: tests.test_archive_file
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_archive\_zip module
-------------------------------

.. automodule:: tests.test_archive_zip
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_axis module
-----------------------

.. automodule:: tests.test_axis
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_dicom module
---------------------------------

.. automodule:: tests.test_formats_dicom
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_dicom\_color module
----------------------------------------

.. automodule:: tests.test_formats_dicom_color
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_dicom\_template module
-------------------------------------------

.. automodule:: tests.test_formats_dicom_template
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_dicom\_zip module
--------------------------------------

.. automodule:: tests.test_formats_dicom_zip
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_itk module
-------------------------------

.. automodule:: tests.test_formats_itk
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_itk\_template module
-----------------------------------------

.. automodule:: tests.test_formats_itk_template
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_itk\_zip module
------------------------------------

.. automodule:: tests.test_formats_itk_zip
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_mat module
-------------------------------

.. automodule:: tests.test_formats_mat
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_mat\_zip module
------------------------------------

.. automodule:: tests.test_formats_mat_zip
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_nifti module
---------------------------------

.. automodule:: tests.test_formats_nifti
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_nifti\_zip module
--------------------------------------

.. automodule:: tests.test_formats_nifti_zip
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_formats\_ps module
------------------------------

.. automodule:: tests.test_formats_ps
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_series module
-------------------------

.. automodule:: tests.test_series
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_transport\_dicomtransport module
--------------------------------------------

.. automodule:: tests.test_transport_dicomtransport
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_transport\_filetransport module
-------------------------------------------

.. automodule:: tests.test_transport_filetransport
   :members:
   :undoc-members:
   :show-inheritance:

tests.test\_version module
--------------------------

.. automodule:: tests.test_version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: tests
   :members:
   :undoc-members:
   :show-inheritance:
